use if ! ( grep { $_ eq '.' } @INC ), qw[lib .];
use lib 'inc';
use Devel::AssertOS qw[Linux];
# This Build.PL for Log-Any-Adapter-LinuxJournal was generated by Dist::Zilla::Plugin::ModuleBuildTiny 0.015.
use strict;
use warnings;

use v5.12.0;
use Module::Build::Tiny 0.034;
Build_PL();
